==> bfilter_1.0.6.orig.tar.gz: bfilter-1.0.6/main/FilteringServer.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2004  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef FILTERINGSERVER_H_
#define FILTERINGSERVER_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "Server.h"
#include "CraftedResponseGenerator.h"
#include <memory>

class HttpRequestMetadata;
class FilterTryList;
class RegexFilterDescriptor;
class RequestTag;
class State;
class URI;

class FilteringServer : public Server
{
public:
	FilteringServer(ServiceContext& context, ServerTimeouts const& timeouts);
	
	virtual ~FilteringServer();
	
	virtual IntrusivePtr<AbstractRequestHandler> submitRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
private:
	class ImageSubstitutionParser;
	class FlashSubstitutionParser;
	
	IntrusivePtr<AbstractRequestHandler> processConnectRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	IntrusivePtr<AbstractRequestHandler> processSubstitutionRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	IntrusivePtr<AbstractRequestHandler> processUrlPatterns(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	IntrusivePtr<AbstractRequestHandler> processAnalyzeRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	void applyStandardFilters(FilterTryList& filters, URI const& request_url);
	
	static bool isFilteringEnabledForURL(State const& state, URI const& url);
};

#endif

==> bfilter_1.1.3.orig.tar.gz: bfilter-1.1.3/main/FilteringServer.h <==
/*
    BFilter - a smart ad-filtering web proxy
    Copyright (C) 2002-2007  Joseph Artsimovich <joseph_a@mail.ru>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

#ifndef FILTERINGSERVER_H_
#define FILTERINGSERVER_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "AbstractServer.h"
#include "IntrusivePtr.h"
#include "RequestPtr.h"

class ServiceContext;
class AbstractRequestHandler;
class AbstractResponseHandler;
class RequestTag;
class HttpRequestMetadata;
class RegexFilterDescriptor;
class State;
class URI;

class FilteringServer : public AbstractServer
{
public:
	FilteringServer(ServiceContext& context, AbstractServer& delegate);
	
	virtual ~FilteringServer();
	
	/**
	 * \brief Submit a request to be filtered.
	 */
	virtual IntrusivePtr<AbstractRequestHandler> submitRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	/**
	 * \brief Submit a request with response attached.
	 * \note This method just forwards this request to the delegate.
	 */
	virtual IntrusivePtr<AbstractRequestHandler> submitRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler,
		std::auto_ptr<ImmediateResponse> response);
	
	virtual bool isIdle() const;
	
	virtual bool isOverloaded() const;
private:
	class ImageSubstitutionParser;
	class FlashSubstitutionParser;
	
	IntrusivePtr<AbstractRequestHandler> processConnectRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	IntrusivePtr<AbstractRequestHandler> processSubstitutionRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	IntrusivePtr<AbstractRequestHandler> processUrlPatterns(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	IntrusivePtr<AbstractRequestHandler> processAnalyzeRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	IntrusivePtr<AbstractRequestHandler> processGenericRequest(
		ConstRequestPtr const& request_metadata,
		RequestTag const& request_tag,
		IntrusivePtr<AbstractResponseHandler> const& handler);
	
	void applyStandardFilters(FilterTryList& filters, URI const& request_url);
	
	static bool isFilteringEnabledForURL(State const& state, URI const& url);
private:
	ServiceContext& m_rContext;
	AbstractServer& m_rDelegate;
};

#endif
